/**
 * JBoss, Home of Professional Open Source
 * Copyright 2008, Red Hat Middleware LLC, and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.webbeans.environment.se.example.simple;

import javax.context.ApplicationScoped;
import javax.event.Observes;
import javax.inject.Produces;
import org.jboss.webbeans.log.Log;
import org.jboss.webbeans.log.Logger;
import org.jboss.webbeans.quartz.annotations.Every;
import org.jboss.webbeans.quartz.events.Minute;
import org.jboss.webbeans.quartz.events.Second;
import org.jfree.data.category.DefaultCategoryDataset;

/**
 * @author Peter Royle
 */
@ApplicationScoped
public class MemoryGrapher
{

    public static final String FREE_MEMORY_LABEL = "Free Memory";

    private DefaultCategoryDataset catDataSet = new DefaultCategoryDataset();

    @Logger Log log;

    @Produces
    public DefaultCategoryDataset getCatDataSet()
    {
        return catDataSet;
    }

    public void perSecond(@Observes @Every Second second)
    {
        getCatDataSet().addValue(Runtime.getRuntime().freeMemory(), FREE_MEMORY_LABEL, new Long(System.currentTimeMillis()).toString());
    }

    public void perMinute(@Observes @Every Minute minute)
    {
//        log.info("Calling garbage collection");
//        System.gc();
    }


}
